==> teiid-engine-7.3.0.Final-sources.jar: org/teiid/query/function/UDFSource.java <==
/*
 * JBoss, Home of Professional Open Source.
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

package org.teiid.query.function;

import java.util.Collection;

import org.teiid.metadata.FunctionMethod;



public class UDFSource implements FunctionMetadataSource {
	
    private Collection <FunctionMethod> methods = null;
    
    public UDFSource(Collection <FunctionMethod> methods) {
    	this.methods = methods;
    }    
    
    public Collection getFunctionMethods() {
        return this.methods;
    }

    public Class getInvocationClass(String className) throws ClassNotFoundException {
        return Class.forName(className);
    }
}

==> teiid-engine-7.4.0.Final-sources.jar: org/teiid/query/function/UDFSource.java <==
/*
 * JBoss, Home of Professional Open Source.
 * See the COPYRIGHT.txt file distributed with this work for information
 * regarding copyright ownership.  Some portions may be licensed
 * to Red Hat, Inc. under one or more contributor license agreements.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 */

package org.teiid.query.function;

import java.util.Collection;

import org.teiid.metadata.FunctionMethod;



public class UDFSource implements FunctionMetadataSource {
	
    private Collection <FunctionMethod> methods = null;
    
    public UDFSource(Collection <FunctionMethod> methods) {
    	this.methods = methods;
    }    
    
    public Collection<FunctionMethod> getFunctionMethods() {
        return this.methods;
    }

    public Class<?> getInvocationClass(String className) throws ClassNotFoundException {
        return Class.forName(className);
    }
}
